import java.util.*; import java.awt.image.*; import java.awt.*;

/*
	Buffer.java 
	(c)1999-2003 SSC Development Team
	Function: Buffering tile images to increase performance
	Allowed Dependencies: All	
	
	- Buffer.java effectively "buffers" the tile images. The source of the tile 
	images are stored in Tile.java. The images themselves are not stored there
	because it prevents the Tiles from being serializable, making it much harder
	to write them to a file properly.
	- Buffer.java also saves some global variables like the current map and the 
	currently selected layer for reference by other classes.
*/

public class Buffer
{
	/* General Stuff */
	
	private static WalkMap cur_map; //current map
	
	public static void setCurMap(Object map) { cur_map = (WalkMap) map; }
	public static WalkMap getCurMap() { return cur_map; }
	
	
	
	/* Game Stuff */
	
	
	private static int CX, CY; //Camera X and Y offset in pixels
	
	public static int  getCX()      { return CX; }
	public static void setCX(int x) { CX = x;    }
	
	public static int  getCY() { return CY; }
	public static void setCY(int y) { CY = y;    }
	
	public static int SX, SY, SF; //TEMP main sprite location
	
	public static int anim_toggle = 0; //TODO: Make private!!
	
    private static Vector sprites = new Vector(); //Array to store Sprites in!
    //TODO: Turn this into an entity vector!!
    
	//returns amount of sprites currently loaded    
    public static int getNumSprites() { 
    	return sprites.size();
    }

    //gets Sprite at given index
    public static Sprite getSprite(int index) { 
    	return (Sprite) sprites.elementAt(index);
    }

    //sets Sprite at given index. Smee & Beta only!
    public static void setSprite(Sprite s, int index) { 
    	sprites.setElementAt(s,index);
    }	

	//sets all Sprites. Useful for loading entire new Spritesets    	
    public static void setSprites(Vector s) { 
    	sprites = s;
    }
    
    //adds a single new Sprite. Smee & Beta only!
    public static void addSprite(Sprite s) {
    	sprites.addElement(s);
    }
    
    //deletes a single Sprite. Smee & Beta only!
    public static void delSprite(int index) {
    	sprites.removeElementAt(index);
    }
    
	/* Note: Smee camera stuff is done within SmeePanel, 
	 * because it's far less complicated than the game camera system
	 */
	
	
	
	/* SMEE Stuff */
	
	
	private static int cur_layer; // selected layer
	private static int curTile; // selected tile
	private static Color curColor = new Color(0,0,0); // selected color
	
	public static void setCurColor(Color a) 
	{	curColor = a; }
	
	public static Color getCurColor() 
	{  	return curColor;	}
	
	public static void setCurTile(int a) 
	{	curTile = a; }
	
	public static int getCurTile() 
	{  	return curTile;	}
	
	public static void setCurLayer(int value)
	{	Buffer.cur_layer = value; }
	
	public static int getCurLayer()
	{	return Buffer.cur_layer; }
	
	
	
	/*
	 *TILE-BUFFERING SECTION
	 *Necessary for both game and Smee!
	 */
	
	private static Vector tiles;
	
	public static void initializeTiles(WalkMap cur_map)
	/*Retrieves and save the BufferedImage objects from the tiles  of the 
	 *current map.
	 */
	{
		int length = cur_map.getTileset().getLength();
		
		tiles = new Vector();
		
		for(int i=0; i<length; i++)
		{
			tiles.addElement(cur_map.getTileset().getTile(i).getSource());
		}	
	}
	
	public static BufferedImage getTile(int index)
	/*Returns a specific tile image
	 */
	{
		return (BufferedImage) tiles.elementAt(index);
	}
	
	public static void addTile()
	{
		tiles.addElement(new Tile().getSource());
	}
}